function Example1

clear all
close all
clc


%% PARAMETERS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
k = 5;  % wave number

% One point source
source_position = [0; -5];
source_strength = [1];

n2 = 128;  % number of discretization points for the far field pattern

noise_level = 0.00;  % relative noise level

R = 10;  % size of region of interest B_R(0)


%% SHOW GEOMETRY %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ShowGeometry(source_position, R);


%% SIMULATE DATA %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
uinfty = ComputeFf_PointSource(source_position, source_strength, k, n2);

% add noise to data
if noise_level > 0
    errvec = rand(size(uinfty))-.5+1i*(rand(size(uinfty))-.5);
    errvec = errvec ./ norm(errvec);
    uinfty = uinfty + errvec * noise_level * norm(uinfty);
    clear errmat
end

ShowFarfield(uinfty)

ShowWave(source_position, source_strength, k, R)


%% FOURIER COEFFICIENTS OF THE FAR FIELD %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ShowFourierSpectrum(uinfty);

new_origin = [0;-5];
uinfty_shifted = ShiftOrigin(uinfty, k, new_origin);
ShowFourierSpectrum(uinfty_shifted);


%% SINGULAR VALUES OF SOURCE-TO-FARFIELD OPERATOR %%%%%%%%%%%%%%%%%%%%%%%%%
nvec = 0:1.3*k*R;

ShowSquaredSingularValuesFR(nvec, R, k);


%% COMPUTE MINIMUM NORM SOLUTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ShowMinimumNormSolution(uinfty, k, R)


%% CONVEX SOURCE SUPPORT %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ShowConvexSourceSupport(uinfty, k, R, source_position)


%% DATA COMPLETION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
z = [0; -5];
R = [1];

% missing data segment Gamma
Gamma = [pi/4, pi/2];
nGammaA = ceil(Gamma(1)*n2/(2*pi));
nGammaB = floor(Gamma(2)*n2/(2*pi));
% observed data umeas
umeas = uinfty;
umeas(nGammaA:nGammaB) = 0;  % apply P_Omega

ShowFarfield(umeas)
title('Observed Far Field','Fontsize',20)

% data completion by alternating projections
nr_of_iterations = 1e2;
urecon = DataCompletion(umeas, k, Gamma, z, R, nr_of_iterations);

ShowFarfield(urecon)
title('Reconstructed Far Field','Fontsize',20)

ShowFarfield(urecon-uinfty)
title('Reconstruction Error','Fontsize',20)


