function ShowConvexSourceSupport(uinfty, k, R, source_position)

%% compute origins for the test circles
nr_of_zls = 32;
r_zls = R/3;
phi_zls = (0:nr_of_zls-1) * 2*pi/nr_of_zls;
c = cos(phi_zls); s = sin(phi_zls);
zls = r_zls * [c; s];  % origins of the test cirlces

Rlvec = zeros(nr_of_zls, 1);  % initialize variable for radii of test circles

%% compute parameterization for test cirles
np = 99;
theta = (0:np)' * 2*pi/np;
c = cos(theta); s = sin(theta);
xhatp = [c, s];  % measurement points


%% intersect circles to approximate convex source support
figure(20)
hold all
for iter = 1 : nr_of_zls  % loop over all origins of test circles
    
    threshold = 1e-3;
    Rlvec(iter) = EstimateRadius(uinfty, k, zls(:,iter), threshold);
    
    figure(20)
    plot(zls(1,iter) + Rlvec(iter)*xhatp(:,1), ...
        zls(2,iter) + Rlvec(iter)*xhatp(:,2))
    
end
figure(20)
nr_of_sources = size(source_position,2);
for iter = 1:nr_of_sources
    plot(source_position(1,iter), source_position(2,iter), 'or', 'linewidth', 2)
end
hold off
axis([-R R -R R]);
grid on
title('Convex source support','Fontsize',20)


end


