function ShowMinimumNormSolution(uinfty, k, R)

n2 = length(uinfty);

threshold = k*R/2; % n2/2;  % bounds the number of singular values that are used


%% 
ft_uinfty = sqrt(2*pi)/n2 * fft(uinfty);  % Fourier coefficients of the far field
ft_uinfty = fftshift(ft_uinfty);
nvec = (-n2/2):(n2/2-1);


%% compute squared singular values of far field operator on B_R(0)
sigma = sqrt( 2*pi * (k*R)^2*pi * ...
    (besselj(nvec,k*R).^2-besselj(nvec-1,k*R).*besselj(nvec+1,k*R)) );


%% compute truncated Picard sum
lambda = 2*pi/k;
xvec = -R:lambda/10:R;
[X,Y] = meshgrid(xvec);
rXY = sqrt(X.^2+Y.^2);
phiXY = atan2(Y,X);

inds = find(rXY>0.9*R);
rXY(inds) = 0;

fstar = zeros(size(X));
for iter = 1:n2
    
    n = nvec(iter);
    
    if abs(n) <= threshold
        
        viter = sqrt(2*pi) .* 1i^n .* exp(1i*n*phiXY) .* besselj(n,k*rXY) / sigma(iter);
        
        fstar = fstar + ft_uinfty(iter)/sigma(iter)*viter;
        
    end
    
end


%% visualize solution
figure()
imagesc(xvec, xvec, real(fstar))
axis([-R,R,-R,R])
axis square xy
title('Minimum norm solution (real part)','Fontsize',20)


